@@ -1,10 +1,12 @@
 
-from cert_schema.jsonld_helpers import jsonld_document_loader, normalize_jsonld
+from cert_schema.jsonld_helpers import jsonld_document_loader, normalize_jsonld, extend_preloaded_context
 from cert_schema.schema_validator import validate_unsigned_v1_2, validate_v1_2, validate_v2, validate_v2_1,\
     validate_v3
+from cert_schema.context_urls import ContextUrls
 
+# Prefer consuming from ContextUrls, maintained here for backwards compatibility, will not get updated
 from cert_schema.jsonld_helpers import BLOCKCERTS_V3_CANONICAL_CONTEXT, BLOCKCERTS_V3_CONTEXT, \
-    VERIFIABLE_CREDENTIAL_V1_CONTEXT, BLOCKCERTS_V2_ALPHA_CONTEXT, BLOCKCERTS_V2_CONTEXT, \
+    VERIFIABLE_CREDENTIAL_V1_CONTEXT, BLOCKCERTS_V2_CONTEXT, \
     BLOCKCERTS_V2_CANONICAL_CONTEXT, \
     BLOCKCERTS_VOCAB, JSONLD_OPTIONS, OPEN_BADGES_V2_CANONICAL_CONTEXT, OPEN_BADGES_V2_CONTEXT, \
     BLOCKCERTS_V2_1_CONTEXT, BLOCKCERTS_V2_1_CANONICAL_CONTEXT
